# Network

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active_state** | **str** |  | [optional] 
**data_center_id** | **str** |  | [optional] 
**external_ip_address** | **str** |  | [optional] 
**gateway** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**init_state** | **str** |  | [optional] 
**internal_ip_address** | **str** |  | [optional] 
**ip_range** | **str** |  | [optional] 
**network_state** | [**NetworkState**](NetworkState.md) |  | [optional] 
**price_hr** | [**Decimal**](Decimal.md) |  | [optional] 
**short_state** | **str** |  | [optional] 
**size** | [**VRouterSize**](VRouterSize.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


